package com.sooka.system.mapper;

import java.util.List;

import com.sooka.common.annotation.DataSource;
import com.sooka.common.enums.DataSourceType;
import com.sooka.system.domain.TgjjDwckzhbdxx;

/**
 * 单位存款账户变动信息Mapper接口
 *
 * @author lei
 * @date 2021-11-16
 */
@DataSource(value = DataSourceType.SLAVE)
public interface TgjjDwckzhbdxxMapper
{
    /**
     * 查询单位存款账户变动信息
     *
     * @param ID 单位存款账户变动信息ID
     * @return 单位存款账户变动信息
     */
    public TgjjDwckzhbdxx selectTgjjDwckzhbdxxById(Long ID);

    /**
     * 查询单位存款账户变动信息列表
     *
     * @param tgjjDwckzhbdxx 单位存款账户变动信息
     * @return 单位存款账户变动信息集合
     */
    public List<TgjjDwckzhbdxx> selectTgjjDwckzhbdxxList(TgjjDwckzhbdxx tgjjDwckzhbdxx);

    /**
     * 新增单位存款账户变动信息
     *
     * @param tgjjDwckzhbdxx 单位存款账户变动信息
     * @return 结果
     */
    public int insertTgjjDwckzhbdxx(TgjjDwckzhbdxx tgjjDwckzhbdxx);

    /**
     * 修改单位存款账户变动信息
     *
     * @param tgjjDwckzhbdxx 单位存款账户变动信息
     * @return 结果
     */
    public int updateTgjjDwckzhbdxx(TgjjDwckzhbdxx tgjjDwckzhbdxx);

    /**
     * 删除单位存款账户变动信息
     *
     * @param ID 单位存款账户变动信息ID
     * @return 结果
     */
    public int deleteTgjjDwckzhbdxxById(Long ID);

    /**
     * 批量删除单位存款账户变动信息
     *
     * @param IDs 需要删除的数据ID
     * @return 结果
     */
    public int deleteTgjjDwckzhbdxxByIds(String[] IDs);
}
